package ${package};

import org.alfresco.repo.node.NodeServicePolicies.OnCreateNodePolicy;
import org.alfresco.repo.policy.Behaviour.NotificationFrequency;
import org.alfresco.repo.policy.JavaBehaviour;
import org.alfresco.service.ServiceRegistry;
import org.alfresco.service.cmr.repository.ChildAssociationRef;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * This class is an example of how you can use the Alfresco Java Public API when Alfresco triggers an event.
 */
@Component
public class ExampleEventListener implements InitializingBean, OnCreateNodePolicy {

    private final Logger logger = LoggerFactory.getLogger(this.getClass());
	
    // this is the Alfresco Public Java API entrypoint
    @Autowired
    protected ServiceRegistry serviceRegistry;
	
	@Override
	public void afterPropertiesSet() throws Exception {
		this.bind();
	}
	
	public void bind() {
		if (this.logger.isTraceEnabled())
			this.logger.trace("bind()");

		// example listener
		this.serviceRegistry.getPolicyComponent().bindClassBehaviour(OnCreateNodePolicy.QNAME, this,
				new JavaBehaviour(this, OnCreateNodePolicy.QNAME.getLocalName(), NotificationFrequency.TRANSACTION_COMMIT));
	}
	
	@Override
	public void onCreateNode(ChildAssociationRef childAssocRef) {
		if (this.logger.isTraceEnabled())
			this.logger.trace("onCreateNode('" + childAssocRef.getChildRef() + "')");
		
		// TODO do some work
	}

}
