package ${package};

import org.alfresco.repo.security.authentication.AuthenticationUtil;
import org.alfresco.repo.security.authentication.AuthenticationUtil.RunAsWork;
import org.alfresco.repo.transaction.RetryingTransactionHelper.RetryingTransactionCallback;
import org.alfresco.service.ServiceRegistry;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.DisposableBean;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * This class is an example of how you can use the Alfresco Java Public API on startup or shutdown.
 */
@Component
public class ExampleBootstrap implements InitializingBean, DisposableBean {

    private final Logger logger = LoggerFactory.getLogger(this.getClass());
	
    // this is the Alfresco Public Java API entrypoint
    @Autowired
    protected ServiceRegistry serviceRegistry;
	
	@Override
	public void afterPropertiesSet() throws Exception {
		if (this.logger.isTraceEnabled())
			this.logger.trace("onStartup()");
		
		// provide some authority within the Alfresco context
		AuthenticationUtil.runAsSystem(new RunAsWork<Void>() {
			@Override
			public Void doWork() throws Exception {
				// provide expected hiccup/concurrency protection
				return ExampleBootstrap.this.serviceRegistry.getRetryingTransactionHelper().doInTransaction(new RetryingTransactionCallback<Void>() {
					@Override
					public Void execute() throws Throwable {
						ExampleBootstrap.this.onStartup();
						return null;
					}
				});
			}
		});
	}
	
	@Override
	public void destroy() throws Exception {
		if (this.logger.isTraceEnabled())
			this.logger.trace("onShutdown()");
		
		// provide some authority within the Alfresco context
		AuthenticationUtil.runAsSystem(new RunAsWork<Void>() {
			@Override
			public Void doWork() throws Exception {
				// provide expected hiccup/concurrency protection
				return ExampleBootstrap.this.serviceRegistry.getRetryingTransactionHelper().doInTransaction(new RetryingTransactionCallback<Void>() {
					@Override
					public Void execute() throws Throwable {
						ExampleBootstrap.this.onShutdown();
						return null;
					}
				});
			}
		});
	}
	
	public void onStartup() {
		// TODO do some work
	}
	
	public void onShutdown() {
		// TODO do some work
	}

}
